@@ -76,9 +76,9 @@ class YOLO_Autorun:
         # print(cmd_prune)
         # os.system(cmd_prune)
         main_autorun(['--admm', 
-                        '--epoch', '1', 
-                        '--cfg', upperpath+'cfg/csdarknet53s-panet-spp.cfg', 
-                        '--data', upperpath+'data/coco2014.data', 
+                        '--epoch', '25', 
+                        '--cfg', 'cfg/csdarknet53s-panet-spp.cfg', 
+                        '--data', 'data/coco2014.data', 
                         '--weights', 'weights/yolov4dense.pt', 
                         '--device', device,
                         '--config-file', prune_file,
@@ -94,24 +94,24 @@ class YOLO_Autorun:
         # print(cmd_retrain)
         # os.system(cmd_retrain)
         main_autorun(['--masked-retrain', 
-                        '--epoch', '1', 
-                        '--cfg', upperpath+'cfg/csdarknet53s-panet-spp.cfg', 
-                        '--data', upperpath+'data/coco2014.data', 
+                        '--epoch', '280', 
+                        '--cfg', 'cfg/csdarknet53s-panet-spp.cfg', 
+                        '--data', 'data/coco2014.data', 
                         '--multi-scale',
                         '--device', device,
                         '--config-file', prune_file,
                         '--sparsity-type', sparsity])
 
-        self.print_info('finish retrain.')
+        self.print_info('finish retrain with the above accuracy.')
 
         # print(cmd_test_retrain)
         # os.system(cmd_test_retrain)
 
-        test_autorun(['--device', device,
-                        '--cfg', upperpath+'cfg/csdarknet53s-panet-spp.cfg',
-                        '--data', upperpath+'data/coco2014.data',
-                        '--weights', 'weights/best.pt'])
-        self.print_info('finish retrain with the above accuracy')
+        # test_autorun(['--device', '0',
+        #                 '--cfg', 'cfg/csdarknet53s-panet-spp.cfg',
+        #                 '--data', 'data/coco2014.data',
+        #                 '--weights', 'weights/best.pt'])
+        # self.print_info('finish retrain with the above accuracy')
 
 
 
