@@ -1,6 +1,6 @@
-from utils.google_utils import *
-from utils.layers import *
-from utils.parse_config import *
+from ModelOpt.AutoYOLO.utils.google_utils import *
+from ModelOpt.AutoYOLO.utils.layers import *
+from ModelOpt.AutoYOLO.utils.parse_config import *
 
 ONNX_EXPORT = False
 
