@@ -1,5 +1,6 @@
 import argparse
 import json
+import torch.distributed as dist
 
 from torch.utils.data import DataLoader
 import glob
@@ -21,12 +22,13 @@ def test(cfg,
          model=None,
          dataloader=None,
          multi_label=True):
-    
-    DATA_CONFIG_PATH = pkg_resources.resource_filename('ModelOpt.AutoYOLO.train', opt.data)
-    data = DATA_CONFIG_PATH
-    
-    cfg = opt.cfg
+
+    import pkg_resources
+    DATA_CONFIG_PATH = pkg_resources.resource_filename('ModelOpt.AutoYOLO.train', data)
     data = DATA_CONFIG_PATH
+    MODEL_CFG_PATH = pkg_resources.resource_filename('ModelOpt.AutoYOLO.train', cfg)
+    cfg = MODEL_CFG_PATH
+
     # Initialize/load model and set device
     if model is None:
         is_training = False
@@ -53,16 +55,25 @@ def test(cfg,
 
         if device.type != 'cpu' and torch.cuda.device_count() > 1:
             model = nn.DataParallel(model)
+            # dist.init_process_group(backend='nccl',  # 'distributed backend'
+            #                         init_method='tcp://127.0.0.1:9919',  # distributed training init method
+            #                         world_size=1,  # number of nodes for distributed training
+            #                         rank=0)  # distributed training node rank
+            # model = torch.nn.parallel.DistributedDataParallel(model, find_unused_parameters=True)
+            
     else:  # called by train.py
         is_training = True
         device = next(model.parameters()).device  # get model device
         verbose = False
-
     # Configure run
     data = parse_data_cfg(data)
+    # print(data)
     nc = 1 if single_cls else int(data['classes'])  # number of classes
     path = data['valid']  # path to test images
-    names = load_classes(data['names'])  # class names
+    
+    CLASS_CFG_PATH = pkg_resources.resource_filename('ModelOpt.AutoYOLO.test', data['names'])
+
+    names = load_classes(CLASS_CFG_PATH)  # class names
     iouv = torch.linspace(0.5, 0.95, 10).to(device)  # iou vector for mAP@0.5:0.95
     iouv = iouv[0].view(1)  # comment for mAP@0.5:0.95
     niou = iouv.numel()
@@ -245,7 +256,7 @@ def test_autorun(arg_list):
     parser.add_argument('--iou-thres', type=float, default=0.5, help='IOU threshold for NMS')
     parser.add_argument('--save-json', action='store_true', help='save a cocoapi-compatible JSON results file')
     parser.add_argument('--task', default='test', help="'test', 'study', 'benchmark'")
-    parser.add_argument('--device', default='', help='device id (i.e. 0 or 0,1) or cpu')
+    parser.add_argument('--device', default='0', help='device id (i.e. 0 or 0,1) or cpu')
     parser.add_argument('--single-cls', action='store_true', help='train as single-class dataset')
     parser.add_argument('--augment', action='store_true', help='augmented inference')
     global opt
