@@ -7,9 +7,9 @@ import json
 
 from torch.utils.data import DataLoader
 
-from models import *
-from utils.datasets import *
-from utils.utils import *
+from ModelOpt.AutoYOLO.models import *
+from ModelOpt.AutoYOLO.utils.datasets import *
+from ModelOpt.AutoYOLO.utils.utils import *
 
 def test_irregular_sparsity(model):
     """
