@@ -8,8 +8,8 @@ import torch.optim.lr_scheduler as lr_scheduler
 import yaml
 from torch.utils.tensorboard import SummaryWriter
 
-import ModelOpt.AutoYOLO.admm
-import ModelOpt.AutoYOLO.test  # import test.py to get mAP after each epoch
+import ModelOpt.AutoYOLO.admm as admm
+import ModelOpt.AutoYOLO.test as test # import test.py to get mAP after each epoch
 from ModelOpt.AutoYOLO.admm import GradualWarmupScheduler
 from ModelOpt.AutoYOLO.models import *
 from ModelOpt.AutoYOLO.check_compression import test_sparsity
@@ -27,6 +27,10 @@ def train(hyp):
         print('Apex recommended for faster mixed precision training: https://github.com/NVIDIA/apex')
         mixed_precision = False  # not installed
 
+    device = torch_utils.select_device(opt.device, apex=mixed_precision, batch_size=opt.batch_size)
+    if device.type == 'cpu':
+        mixed_precision = False
+
     wdir = 'weights' + os.sep  # weights dir
     last = wdir + 'last.pt'
     best = wdir + 'best.pt'
@@ -35,8 +39,9 @@ def train(hyp):
     import pkg_resources
     PRUNE_CONFIG_PATH = pkg_resources.resource_filename('ModelOpt.AutoYOLO.train', 'prune_config/'+ opt.config_file + ".yaml")
     DATA_CONFIG_PATH = pkg_resources.resource_filename('ModelOpt.AutoYOLO.train', opt.data)
+    MODEL_CFG_PATH = pkg_resources.resource_filename('ModelOpt.AutoYOLO.train', opt.cfg)
 
-    cfg = opt.cfg
+    cfg = MODEL_CFG_PATH
     data = DATA_CONFIG_PATH
     epochs = opt.epochs  # 500200 batches at bs 64, 117263 images = 273 epochs
     batch_size = opt.batch_size
@@ -256,8 +261,8 @@ def train(hyp):
                 print(('\n' + '%10s' * 8) % ('Epoch', 'gpu_mem', 'GIoU', 'obj', 'cls', 'total', 'targets', 'img_size'))
                 pbar = tqdm(enumerate(dataloader), total=nb)  # progress bar
                 for i, (imgs, targets, paths, _) in pbar:  # batch -------------------------------------------------------------
-                    if i >2:
-                        break
+                    # if i >2:
+                    #     break
                     ni = i + nb * epoch  # number integrated batches (since train start)
                     imgs = imgs.to(device).float() / 255.0  # uint8 to float32, 0 - 255 to 0.0 - 1.0
                     targets = targets.to(device)
@@ -393,7 +398,7 @@ def train(hyp):
             plot_results()  # save as results.png
         print('%g epochs completed in %.3f hours.\n' % (epoch - start_epoch + 1, (time.time() - t0) / 3600))
         # dist.destroy_process_group() if torch.cuda.device_count() > 1 else None
-        # torch.cuda.empty_cache()
+        torch.cuda.empty_cache()
         # return results
 
 
@@ -443,10 +448,10 @@ def train(hyp):
 
         # Initialize distributed training
         if device.type != 'cpu' and torch.cuda.device_count() > 1 and torch.distributed.is_available():
-            dist.init_process_group(backend='nccl',  # 'distributed backend'
-                                    init_method='tcp://127.0.0.1:9919',  # distributed training init method
-                                    world_size=1,  # number of nodes for distributed training
-                                    rank=0)  # distributed training node rank
+            # dist.init_process_group(backend='nccl',  # 'distributed backend'
+            #                         init_method='tcp://127.0.0.1:9919',  # distributed training init method
+            #                         world_size=1,  # number of nodes for distributed training
+            #                         rank=0)  # distributed training node rank
             model = torch.nn.parallel.DistributedDataParallel(model, find_unused_parameters=True)
             model.yolo_layers = model.module.yolo_layers  # move yolo layer indices to top level
 
@@ -505,8 +510,8 @@ def train(hyp):
             print(('\n' + '%10s' * 8) % ('Epoch', 'gpu_mem', 'GIoU', 'obj', 'cls', 'total', 'targets', 'img_size'))
             pbar = tqdm(enumerate(dataloader), total=nb)  # progress bar
             for i, (imgs, targets, paths, _) in pbar:  # batch -------------------------------------------------------------
-                if i >2:
-                    break
+                # if i >2:
+                #     break
                 ni = i + nb * epoch  # number integrated batches (since train start)
                 imgs = imgs.to(device).float() / 255.0  # uint8 to float32, 0 - 255 to 0.0 - 1.0
                 targets = targets.to(device)
@@ -595,8 +600,8 @@ def train(hyp):
             if not opt.notest or final_epoch:  # Calculate mAP
                 is_coco = any(
                     [x in data for x in ['coco.data', 'coco2014.data', 'coco2017.data']]) and model.nc == 80
-                results, maps = test.test(cfg,
-                                          data,
+                results, maps = test.test(opt.cfg,
+                                          opt.data,
                                           batch_size=batch_size,
                                           imgsz=imgsz_test,
                                           model=ema.ema,
@@ -604,6 +609,7 @@ def train(hyp):
                                           single_cls=opt.single_cls,
                                           dataloader=testloader,
                                           multi_label=ni > n_burn)
+                # results, maps = None, None
 
             # Write
             with open(results_file, 'a') as f:
@@ -661,12 +667,15 @@ def train(hyp):
                     os.system('gsutil cp %s gs://%s/weights' % (
                     f2, opt.bucket)) if opt.bucket and ispt else None  # upload
 
-        if not opt.evolve:
-            plot_results()  # save as results.png
+        # if not opt.evolve:
+        #     plot_results()  # save as results.png
         print('%g epochs completed in %.3f hours.\n' % (epoch - start_epoch + 1, (time.time() - t0) / 3600))
         # dist.destroy_process_group() if torch.cuda.device_count() > 1 else None
-        # torch.cuda.empty_cache()
+        torch.cuda.empty_cache()
+        del model
+        del ema
         return results
+    
 
 def main_autorun(arg_list):
     global mixed_precision
@@ -733,7 +742,7 @@ def main_autorun(arg_list):
     parser.add_argument('--admm', action='store_true', help='do admm process')
     parser.add_argument('--masked-retrain', action='store_true', help='do masked-retrain process')
     parser.add_argument('--rho', default=0.0001, help='rho val')
-    parser.add_argument('--rho-num', default=1, help='order of magnitude （from 0.0001 x 1e-1 to 0.0001 x 1e-4)')
+    parser.add_argument('--rho-num', default=4, help='order of magnitude （from 0.0001 x 1e-1 to 0.0001 x 1e-4)')
     parser.add_argument('--admm-epochs', default=6, help='rho val')
     parser.add_argument('--sparsity-type', type=str, default='block-punched', help='order of magnitude （from 0.0001 x 1e-1 to 0.0001 x 1e-4)')
     parser.add_argument('--config-file', type=str, default='config_csdarknet53pan_v14', help='prune ratio config file')
@@ -759,10 +768,10 @@ def main_autorun(arg_list):
     # opt.data = check_file(opt.data)  # check file
     print(opt)
     opt.img_size.extend([opt.img_size[-1]] * (3 - len(opt.img_size)))  # extend to 3 sizes (min, max, test)
-    global device
-    device = torch_utils.select_device(opt.device, apex=mixed_precision, batch_size=opt.batch_size)
-    if device.type == 'cpu':
-        mixed_precision = False
+    # global device
+    # device = torch_utils.select_device(opt.device, apex=mixed_precision, batch_size=opt.batch_size)
+    # if device.type == 'cpu':
+    #     mixed_precision = False
 
     global tb_writer
     tb_writer = None
@@ -865,10 +874,8 @@ if __name__ == '__main__':
     print(opt)
     opt.img_size.extend([opt.img_size[-1]] * (3 - len(opt.img_size)))  # extend to 3 sizes (min, max, test)
     
-    global device
-    device = torch_utils.select_device(opt.device, apex=mixed_precision, batch_size=opt.batch_size)
-    if device.type == 'cpu':
-        mixed_precision = False
+    # global device
+
 
     
     # tb_writer = None
