@@ -55,7 +55,7 @@ def check_file(file):
 
 def load_classes(path):
     # Loads *.names file at 'path'
-    with open('ModelOpt/AutoYOLO/'+path, 'r') as f:
+    with open(path, 'r') as f:
         names = f.read().split('\n')
     return list(filter(None, names))  # filter removes empty strings (such as last line)
 
